#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5784 $
$LastChangedDate:: 2022-04-21 10:13:47 +0200#$

This file is part of SyMSpace.

Copyright (c) 2019, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import open_webservice
from symspace.parampythonfnc import ParamPythonFnc
from symspace.decorators import remotecompute
from open_webservice.heroku.client import HerokuClient


@remotecompute('(PYTHON >= \"3.5.3\")')
# @remotecompute('(PYTHON >= \"3.5.3\")', variation=['a', 'b'])
# @debugexternal
class FncHerokuClient(ParamPythonFnc):
    """ Heroku Client Python Function
    
    SyMSpace Heroku Client Template class,
    which shows the basic implementation of a Heroku Client Python function.

    """

    def importVars(self):
        """Description of the import variables

        Returns a list of tuples, which defines the import variables.
        Each tuple consists of multiple entries in the following order:

        (Name : string, Description : string, Unit : string, Optional : bool, Type / Dimension : string)

        """
        return [('a', 'Adjacent leg', 'mm', False, 'Numeric / [1 x 1]'),
                ('b', 'Opposite leg', 'mm', False, 'Numeric / [1 x 1]')]

    def exportVars(self):
        """Description of the export variables

        Returns a list of tuples, which defines the export variables.
        Each tuple consists of multiple entries in the following order:

        (Name : string, Description : string, Unit : string, Optional : bool, Type / Dimension : string)

        """
        return [('c', 'Hypotenuse', 'mm', False, 'Numeric / [1 x 1]')]

    def getAdditionalPackages(self) -> list:
        pkg_list = [os.path.dirname(open_webservice.__file__)]
        return pkg_list

    def run(self, run_args):
        """Run method of the function, which calculates the result

        Parameters
        ----------
        run_args : dict
                Arguments of caller (Control flags)
                {RemoteCompute=false, RunSim=false, Optimize=false}

        Returns
        -------
        status : int
            If status == 0 the function regenerated successfully
            Else the function update is not completed OR failed

        """

        '''import variables from ports'''
        d = self.importValues()

        ''' Default local heroku server settings
        server_uri = "localhost"
        server_port = 5000
        '''
        server_uri = "__server_uri__"  # this parameter is likely to never change
        server_port = 0

        input_data = dict(a=d['a'], b=d['b'])

        hc = HerokuClient(server_uri, server_port)
        output_data = hc.send_data(input_data)
        d['c'] = output_data['c']

        '''export variables to ports'''
        self.exportValues(d)

        return 0
