#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5843 $
$LastChangedDate:: 2022-05-03 07:58:28 +0200#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
import shutil
import json
import glob
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.font_manager import FontProperties

from symspace.wrapper.symwrapper import SymProject

import componentspace.osutils.fileutils as fu
from componentspace.geometry_utils.geometry_functions import GeneralGeometryFunctions
from componentspace.geometry_utils.batch_geometry import GeometryBatchComponent


class HEWGeometry(GeometryBatchComponent):
    """

    """

    def _createSingleCompfileFromTemplate(self, comp_file: str, geometry: dict):
        path_geometry = os.path.dirname(comp_file)
        component_name = geometry['component_name']

        '''Copy rst'''
        fu.copyFileAndReplace(os.path.join(self.base_directory, 'index.rst'),
                              os.path.join(path_geometry, 'index.rst'),
                              [('__ComponentTitle__',
                                component_name + '\n' + len(component_name) * '=')]) # ,
                               # ('__Comment__', material['comment']),
                               # ('__MaterialName__', material['name']),
                               # ('__Manufacturer__', material['manufacturer']),
                               # ('__BHCurve__', (component_name + '_bhcurve_plot.png')),
                               # ('__LossCoeff__', (component_name + '_loss_coeff_plot.png')),
                               # ('__PDF__', material['pdf_file']),
                               # ('__EXCEL__', material['excel_file'])])

        fu.copyTree(os.path.join(self.base_directory, 'rst'), os.path.join(path_geometry, 'rst'))
        fu.copyTree(os.path.join(self.base_directory, 'src'), os.path.join(path_geometry, 'src'))

        # '''Copy pdf'''
        # pdf_file = os.path.join(self.base_directory, 'resources', material['pdf_file'])
        # if os.path.isfile(pdf_file):
        #     shutil.copy(pdf_file, os.path.join(path_material, 'rst', material['pdf_file']))
        #
        # '''Copy excel file'''
        # excel_file = os.path.join(self.base_directory, 'resources', material['excel_file'])
        # if os.path.isfile(excel_file):
        #     shutil.copy(excel_file, os.path.join(path_material, 'rst', material['excel_file']))
        #
        # '''Copy png file'''
        # bhcurve_png_file = os.path.join(path_material, 'rst', (component_name + '_bhcurve_plot.png'))
        # self.plot_bhcurve(material, bhcurve_png_file)
        #
        # losscoeff_png_file = os.path.join(path_material, 'rst', (component_name + '_loss_coeff_plot.png'))
        # self.plot_losscoefficients(material, losscoeff_png_file)

        '''Modify material file'''
        prj = SymProject.load(comp_file)
        # prj['Project.Material.Type'].setData('Ferromagnetic material')
        # prj['Project.Material.Name'].setData(component_name)

        GeneralGeometryFunctions.set_filter(prj, geometry)
        GeneralGeometryFunctions.set_info(prj, geometry)
        GeneralGeometryFunctions.set_dxf(prj, geometry)
        GeneralGeometryFunctions.set_geometry_properties(prj, geometry)
        # GeneralMaterialFunctions.set_electromagnetic_properties(prj, material)
        # GeneralMaterialFunctions.set_mechanic_properties(prj, material)
        # GeneralMaterialFunctions.set_thermal_properties(prj, material)

        prj.save()
