#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 6060 $
$LastChangedDate:: 2022-08-09 10:35:41 +0200#$

This file is part of SyMSpace.

Copyright (c) 2017, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
import shutil

from symspace.wrapper.symwrapper import SymProject

import componentspace.osutils.fileutils as fu
from componentspace.material_utils.material_functions import GeneralMaterialFunctions
from componentspace.material_utils.batch_material import MaterialBatchComponent


class MaterialNonferrousMetal(MaterialBatchComponent):
    """

    """

    def _createSingleCompfileFromTemplate(self, comp_file: str, material: dict):
        """
        Creates a directory with the name of the geometry and the component class
        Copies directories /rst, /help, and /doc

        Parameters
        ----------
        material : dict
           Dictionary of material properties

        """

        path_material = os.path.dirname(comp_file)
        component_name = material['component_name']

        # Create material directory
        if not os.path.exists(path_material):
            os.mkdir(path_material)

        '''Copy rst'''
        fu.copyFileAndReplace(os.path.join(self.path, 'index.rst'),
                              os.path.join(path_material, 'index.rst'),
                              [('__ComponentTitle__', component_name + '\n' + len(component_name) * '='),
                               ('__Comment__', material['comment']),
                               ('__MaterialName__', material['name']),
                               # ('__MaterialNumber__', material['DIN EN']['value']),
                               ('__Manufacturer__', material['manufacturer']),
                               ('__PDF__', material['pdf_file'])])

        fu.copyTree(os.path.join(self.path, 'rst'), os.path.join(path_material, 'rst'))

        '''Copy pdf'''
        pdf_file = os.path.join(self.path, 'resources', material['pdf_file'])
        if os.path.isfile(pdf_file):
            shutil.copy(pdf_file, os.path.join(path_material, 'rst', material['pdf_file']))

        '''Modify material file'''
        prj = SymProject.load(comp_file)
        
        GeneralMaterialFunctions.set_filter(prj, material)
        GeneralMaterialFunctions.set_info(prj, material)
        GeneralMaterialFunctions.set_general_properties(prj, material)
        GeneralMaterialFunctions.set_electromagnetic_properties(prj, material)
        GeneralMaterialFunctions.set_mechanic_properties(prj, material)
        GeneralMaterialFunctions.set_thermal_properties(prj, material)

        prj.save()

